@@ -474,6 +474,11 @@ namespace rocalution
                     this->q_level_[i]->MoveToHost();
                 }
             }
+
+            if(this->precond_ != NULL)
+            {
+                this->precond_->MoveToHost();
+            }
         }
     }
 
@@ -547,6 +552,11 @@ namespace rocalution
                     }
                 }
             }
+
+            if(this->precond_ != NULL)
+            {
+                this->precond_->MoveToAccelerator();
+            }
         }
     }
 
